==> ZenTaoPMS-ipd1.2-php5.4_5.6.zip: zentaopms/module/account/model.php <==
<?php
/**
 * The model file of account module of ChanzhiEPS.
 *
 * @copyright   Copyright 2009-2010 QingDao Nature Easy Soft Network Technology Co,LTD (www.cnezsoft.com)
 * @license     ZPL (http://zpl.pub/page/zplv11.html)
 * @author      Xiying Guan <guanxiying@xirangit.com>
 * @package     account
 * @version     $Id$
 * @link        https://www.zentao.net
 */
class accountModel extends model
{
    /**
     * Get account by id.
     *
     * @param  int    $id
     * @access public
     * @return object
     */
    public function getByID($id)
    {
        return $this->dao->select('*')->from(TABLE_ACCOUNT)->where('id')->eq($id)->fetch();
    }

    /**
     * Get accounts by id list.
     *
     * @param  int    $idList
     * @access public
     * @return array
     */
    public function getByIdList($idList)
    {
        return $this->dao->select('*')->from(TABLE_ACCOUNT)->where('id')->in($idList)->fetchAll('id');
    }

    /**
     * Get account list.
     *
     * @param  string $browseType
     * @param  int    $param
     * @param  string $orderBy
     * @param  object $pager
     * @access public
     * @return array
     */
    public function getList($browseType = 'all', $param = 0, $orderBy = 't1.id_desc', $pager = null)
    {
        $query   = '';
        if($browseType == 'bysearch')
        {
            /* Concatenate the conditions for the query. */
            if($param)
            {
                $query = $this->loadModel('search')->getZinQuery($param);
                if($query)
                {
                    $this->session->set('accountQuery', $query->sql);
                    $this->session->set('accountForm', $query->form);
                }
            }
            else
            {
                if(!$this->session->accountQuery) $this->session->set('accountQuery', ' 1 = 1');
            }
            $query = $this->session->accountQuery;
        }

        $accounts = $this->dao->select('*')->from(TABLE_ACCOUNT)
            ->where('deleted')->eq('0')
            ->beginIF($query)->andWhere($query)->fi()
            ->orderBy($orderBy)
            ->page($pager)
            ->fetchAll();

        $users = $this->loadModel('user')->getPairs('noclosed|nodeleted|noletter');
        foreach($accounts as $account) $account->createdBy = zget($users, $account->createdBy, '');

        return $accounts;
    }

    /**
     * Get account pairs
     *
     * @access public
     * @return array
     */
    public function getPairs()
    {
        return $this->dao->select('id,name')->from(TABLE_ACCOUNT)->where('deleted')->eq('0')->fetchPairs();
    }

    public function create()
    {
        $account = fixer::input('post')
            ->setDefault('createdBy', $this->app->user->account)
            ->setDefault('createdDate', helper::now())
            ->get();

        $this->dao->insert(TABLE_ACCOUNT)
            ->data($account)
            ->batchCheck($this->config->account->create->requiredFields, 'notempty')
            ->checkIf($account->email, 'email', 'email')
            ->checkIf($account->mobile, 'mobile', 'mobile')
            ->exec();

        if(dao::isError()) return false;
        return $this->dao->lastInsertID();
    }

    /**
     * Update one account.
     *
     * @param  int    $id
     * @access public
     * @return void
     */
    public function update($id)
    {
        $now        = helper::now();
        $oldAccount = $this->getByID($id);
        $newAccount = fixer::input('post')
            ->add('editedBy', $this->app->user->account)
            ->add('editedDate', $now)
            ->get();

        $this->dao->update(TABLE_ACCOUNT)->data($newAccount)->autoCheck()
            ->batchCheck($this->config->account->edit->requiredFields, 'notempty')
            ->checkIf($newAccount->email, 'email', 'email')
            ->checkIf($newAccount->mobile, 'mobile', 'mobile')
            ->where('id')->eq($id)
            ->exec();

        if(!dao::isError()) return common::createChanges($oldAccount, $newAccount);
        return false;
    }
}

==> ZenTaoPMS-ipd2.6.1-php7.2_7.4.zip: zentaopms/module/account/model.php <==
<?php
/**
 * The model file of account module of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2023 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.cnezsoft.com)
 * @license     ZPL (http://zpl.pub/page/zplv11.html)
 * @author      Xiying Guan <guanxiying@xirangit.com>
 * @package     account
 * @link        https://www.zentao.net
 */
class accountModel extends model
{
    /**
     * 获取账号列表。
     * Get account list.
     *
     * @param  string $browseType
     * @param string $param
     * @param  string $orderBy
     * @param  object $pager
     * @access public
     * @return array
     */
    public function getList($browseType = 'all', $param = '', $orderBy = 'id_desc', $pager = null)
    {
        $query = '';
        if($browseType == 'bysearch')
        {
            /* Concatenate the conditions for the query. */
            if(!$this->session->accountQuery) $this->session->set('accountQuery', ' 1 = 1');
            if($param)
            {
                $query = $this->loadModel('search')->getQuery((int)$param);
                if($query)
                {
                    $this->session->set('accountQuery', $query->sql);
                    $this->session->set('accountForm', $query->form);
                }
            }
            $query = $this->session->accountQuery;
        }

        $accounts = $this->dao->select('*')->from(TABLE_ACCOUNT)
            ->where('deleted')->eq('0')
            ->beginIF($query)->andWhere($query)->fi()
            ->orderBy($orderBy)
            ->page($pager)
            ->fetchAll();

        $users = $this->loadModel('user')->getPairs('noclosed|nodeleted|noletter');
        foreach($accounts as $account) $account->createdBy = zget($users, $account->createdBy, '');

        return $accounts;
    }

    /**
     * 获取账号的id:name键值对。
     * Get account pairs.
     *
     * @access public
     * @return array
     */
    public function getPairs()
    {
        return $this->dao->select('id,name')->from(TABLE_ACCOUNT)->where('deleted')->eq('0')->fetchPairs();
    }

    /**
     * 创建一个账号。
     * Create account.
     *
     * @param  object $account
     * @access public
     * @return int|false
     */
    public function create($account)
    {
        $this->dao->insert(TABLE_ACCOUNT)->data($account)
            ->batchCheck($this->config->account->create->requiredFields, 'notempty')
            ->checkIf($account->email, 'email', 'email')
            ->checkIf($account->mobile, 'mobile', 'mobile')
            ->exec();
        if(dao::isError()) return false;

        $accountID = $this->dao->lastInsertID();
        $this->loadModel('action')->create('account', $accountID, 'created');
        return $accountID;
    }

    /**
     * 更新一个账号。
     * Update one account.
     *
     * @param  int    $id
     * @param  object $account
     * @access public
     * @return bool
     */
    public function update($id, $account)
    {
        $oldAccount = $this->fetchByID($id);
        $this->dao->update(TABLE_ACCOUNT)->data($account)->autoCheck()
            ->batchCheck($this->config->account->edit->requiredFields, 'notempty')
            ->checkIf($account->email, 'email', 'email')
            ->checkIf($account->mobile, 'mobile', 'mobile')
            ->where('id')->eq($id)
            ->exec();

        if(!dao::isError())
        {
            $changes = common::createChanges($oldAccount, $account);
            if(empty($changes)) return true;

            $actionID = $this->loadModel('action')->create('account', $id, 'Edited');
            $this->action->logHistory($actionID, $changes);
            return true;
        }
        return false;
    }
}
